@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: assign_templates.py 9850 2017-04-08 14:24:13Z Lavender $
+# $Id: build_templates.py 9976 2017-05-16 06:31:28Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-08 22:24:13 +0800 (週六, 08 四月 2017) $
-# $Revision: 9850 $
+# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
+# $Revision: 9976 $
 
 import os
 import sys
@@ -21,6 +21,8 @@ import logging
 
 from django.core.management.base import BaseCommand, CommandError
 
+from Zephyrus.boilerplate.management.commands import TEMPLATES_DIR_PATH
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 handler = logging.StreamHandler()
@@ -28,10 +30,6 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
-TEMPLATES_DIR_PATH = os.path.abspath(
-    os.path.join(__file__, '..', '..', '..', '..', 'templates'))
-
-
 class Command(BaseCommand):
 
     help = 'Start build all template to dst folder.'
