@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 9878 2017-04-17 06:04:20Z Lavender $
+# $Id: create_zip.py 9978 2017-05-20 15:24:37Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-17 14:04:20 +0800 (週一, 17 四月 2017) $
-# $Revision: 9878 $
+# $Date: 2017-05-20 23:24:37 +0800 (週六, 20 五月 2017) $
+# $Revision: 9978 $
 
 import os
 import logging
@@ -24,7 +24,10 @@ import hashlib
 
 from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
-from django.conf import settings
+
+from Zephyrus.boilerplate.management.commands import (
+    TEMPLATES_DIR_PATH, STATIC_DIR_PATH, 
+    IMAGES_DIR_PATH, ROOT_DIR_PATH, FIXTURES_DIR_PATH)
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -33,28 +36,6 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
-if hasattr(settings, 'TEMPLATES'):
-    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
-else:
-    TEMPLATES_DIR_PATH = os.path.abspath(
-        os.path.join('.', 'templates'))
-
-if settings.DEBUG:
-    if hasattr(settings, 'STATICFILES_DIRS'):
-        STATIC_DIT_PATH = settings.STATICFILES_DIRS[0]
-    else:
-        STATIC_DIT_PATH = os.path.abspath(
-            os.path.join('.', 'static'))
-
-FIXTURES_DIT_PATH = os.path.abspath(
-    os.path.join('.', 'fixtures'))
-
-ROOT_DIR_PATH = os.path.abspath(
-    os.path.join('.'))
-    
-IMAGES_DIT_PATH = os.path.abspath(
-    os.path.join('.', 'images'))
-
 class Command(BaseCommand):
 
     help = 'Create zip file to destination folder.'
@@ -93,15 +74,17 @@ class Command(BaseCommand):
                 dst = "./templates/%s" % file
                 logger.info("Zip " + path)
                 zip.write(path, dst)
-                
-        index = len(TEMPLATES_DIR_PATH) + 1
-        for root, dirs, files in os.walk(STATIC_DIT_PATH):
+        
+        
+        index = len(STATIC_DIR_PATH) + 1
+        for root, dirs, files in os.walk(STATIC_DIR_PATH):
             for file in files:
                 path = os.path.join(root, file)
+                
                 dst = "./static/%s" % path[index:]
                 logger.info("Zip " + path)
                 zip.write(path, dst)
-        for root, dirs, files in os.walk(FIXTURES_DIT_PATH):
+        for root, dirs, files in os.walk(FIXTURES_DIR_PATH):
             for file in files:
                 path = 'fixtures/%s' % file
                 logger.info("Zip " + path)
@@ -131,7 +114,7 @@ class Command(BaseCommand):
             os.path.join(dst, '%s.zip' % data['upc']), mode='w')
         zip.write('info.json')
         
-        for root, dirs, files in os.walk(IMAGES_DIT_PATH):
+        for root, dirs, files in os.walk(IMAGES_DIR_PATH):
             for file in files:
                 path = 'images/%s' % file
                 logger.info("Zip " + path)
@@ -140,10 +123,10 @@ class Command(BaseCommand):
         zip.write('template.zip')
         zip.close()
         
-        if os.path.exists(FIXTURES_DIT_PATH):
-            shutil.rmtree(FIXTURES_DIT_PATH)
-        if os.path.exists(IMAGES_DIT_PATH):
-            shutil.rmtree(IMAGES_DIT_PATH)
+        if os.path.exists(FIXTURES_DIR_PATH):
+            shutil.rmtree(FIXTURES_DIR_PATH)
+        if os.path.exists(IMAGES_DIR_PATH):
+            shutil.rmtree(IMAGES_DIR_PATH)
         if os.path.isfile('./README.txt'):
             os.remove('./README.txt')
         if os.path.isfile('./setup.py'):
