@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 9929 2017-04-30 04:56:40Z Lavender $
+# $Id: setup.py 9976 2017-05-16 06:31:28Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-30 12:56:40 +0800 $
-# $Revision: 9929 $ 
+# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
+# $Revision: 9976 $ 
 
 import os
 import sys
@@ -35,7 +35,7 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
-def copyToPath(baseDir, templateDir, staticDir):
+def copyToPath(baseDir, templateDir, staticDir, mode):
     logger.info("-----Start copy templates-----")
     for root, dirs, files in os.walk(os.path.join(SETUP_DIR, "static")):
         for d in dirs:
@@ -55,7 +55,15 @@ def copyToPath(baseDir, templateDir, staticDir):
                 index = len(os.path.join(SETUP_DIR, "static")) + 1
                 dst = os.path.join(staticDir, origin[index:])
             elif "templates" in root:
-                dst = os.path.join(templateDir, f)
+                if mode == 'programmer':
+                    if 'Fix' in f:
+                        continue
+                    dst = os.path.join(templateDir, f)
+                else:
+                    if 'Fix' not in f:
+                        continue
+                    dst = os.path.join(
+                        templateDir, f.replace('Fix.html', '.html'))
             elif "fixtures" in root:
                 index = len(os.path.join(SETUP_DIR, "fixtures")) + 1
                 dst = os.path.join(baseDir, "fixtures", origin[index:])
@@ -85,6 +93,8 @@ def writeSettings(settingsPath, templateDir):
         index = None
                 
         for template in os.listdir(path):
+            if "Fix" in template:
+                continue
             if template.lower() == 'index.html':
                 index = template
                 continue
@@ -128,8 +138,20 @@ def loadData(language):
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description='Path to Project')
-    parser.add_argument('path', metavar='path', type=str, help='path')                   
+    parser.add_argument('path', metavar='path', type=str, help='path')
+    parser.add_argument(
+        '-m', '--mode', 
+        default='programmer',
+        choices=['programmer', 'user',],
+        help='programmer mode or user mode.')
+    
     args = parser.parse_args()
+    
+    if args.mode == 'programmer':
+        mode = 'programmer'
+    else:
+        mode = 'user'
+    
     settingsPath = findSettings(args.path)
     
     settingModule = os.path.splitext(settingsPath[len(args.path) + 1:])[0]
@@ -149,6 +171,9 @@ if __name__ == "__main__":
     if hasattr(settings, "STATICFILES_DIRS"):
         staticDir = settings.STATICFILES_DIRS[0]
     
-    copyToPath(args.path, templateDir, staticDir)
+    copyToPath(args.path, templateDir, staticDir, mode)
+    
     writeSettings(settingsPath, templateDir)
     loadData(settings.LANGUAGE_CODE)
+    
+    
\ No newline at end of file
